@@ -1,11 +1,11 @@
-#$Id: Instrument.pm 272 2005-12-12 00:56:50Z schroeer $
+#$Id: Instrument.pm 475 2006-08-10 22:06:46Z schroeer $
 
 package Lab::Instrument;
 
 use strict;
 use Lab::VISA;
 
-our $VERSION = sprintf("1.%04d", q$Revision: 272 $ =~ / (\d+) /);
+our $VERSION = sprintf("1.%04d", q$Revision: 475 $ =~ / (\d+) /);
 
 sub new {
     my $proto = shift;
@@ -97,6 +97,7 @@ sub Write {
 }
 
 sub Query {
+    # contains a nice bomb: read_cnt is arbitrarly set to 300 bytes
     my $self=shift;
     my $cmd=shift;
     my ($status, $write_cnt)=Lab::VISA::viWrite(
@@ -111,6 +112,15 @@ sub Query {
     return substr($result,0,$read_cnt);
 }
 
+sub Read {
+    my $self=shift;
+    my $length=shift;
+
+    my ($status,$result,$read_cnt)=Lab::VISA::viRead($self->{instr},$length);
+    if ($status != $Lab::VISA::VI_SUCCESS) { die "Error while reading: $status";}
+    return substr($result,0,$read_cnt);
+}
+
 sub Handle {
     my $self=shift;
     return $self->{instr};
@@ -138,40 +148,62 @@ Lab::Instrument - General VISA based instrument
 =head1 DESCRIPTION
 
 C<Lab::Instrument> offers an abstract interface to an instrument, that is connected via
-GPIB, serial connection or ethernet. It provides general C<read>, C<write> and C<query> methods,
+GPIB, serial bus or ethernet. It provides general C<Read>, C<Write> and C<Query> methods,
 and more.
 
 It can be used either directly by the laborant (programmer) to work with
 an instrument that doesn't have its own perl class
-(like Lab::Instrument::HP34401A). Or it can be used by such a specialized
-perl instrument class (like Lab::Instrument::HP34401A), to delegate the
+(like L<Lab::Instrument::HP34401A|Lab::Instrument::HP34401A>). Or it can be used by such a specialized
+perl instrument class (like C<Lab::Instrument::HP34401A>), to delegate the
 actual visa work. (All the instruments in the default package do so.)
 
-=head1 CONSTRUCTORS
+=head1 CONSTRUCTOR
 
 =head2 new
 
- $instrument=new Lab::Instrument($gpib_board,$gpib_addr);
+ $instrument=new Lab::Instrument($board,$addr);
  $instrument2=new Lab::Instrument({GPIB_board => $board, GPIB_address => $addr});
- 
+
+Creates a new instrument object and open the instrument with GPIB address C<$addr>
+connected to the GPIB board C<$board> (usually 0). All instrument classes that
+internally use the C<Lab::Instrument> module (that's all instruments in the default
+distribution) can use both forms of the constructor.
+
 =head1 METHODS
 
 =head2 Write
 
  $write_count=$instrument->Write($command);
+ 
+Sends the command C<$command> to the instrument.
+
+=head2 Read
+
+ $result=$instrument->Read($length);
+
+Reads a result of maximum length C<$length> from the instrument and returns it.
 
 =head2 Query
 
  $result=$instrument->Query($command);
 
+Sends the command C<$command> to the instrument and reads a result from the
+instrument and returns it. The length of the read buffer is haphazardly
+set to 300 bytes. This can be changed in the source code, hehe. Or you use
+seperate C<Write> and C<Read> commands.
+
 =head2 Clear
 
  $instrument->Clear();
 
+Sends a clear command to the instrument.
+
 =head2 Handle
 
  $instr_handle=$instrument->Handle();
 
+Returns the VISA handle. You can use this handle with the L<Lab::VISA> module.
+
 =head1 CAVEATS/BUGS
 
 Probably many.
@@ -182,13 +214,27 @@ Probably many.
 
 =item L<Lab::VISA>
 
+=item L<Lab::Instrument::HP34401A>
+
+=item L<Lab::Instrument::HP34970A>
+
+=item L<Lab::Instrument::Source>
+
+=item L<Lab::Instrument::KnickS252>
+
+=item L<Lab::Instrument::Yokogawa7651>
+
+=item L<Lab::Instrument::SR780>
+
+=item L<Lab::Instrument::IPS120_10>
+
 =back
 
 =head1 AUTHOR/COPYRIGHT
 
-This is $Id: Instrument.pm 272 2005-12-12 00:56:50Z schroeer $
+This is $Id: Instrument.pm 475 2006-08-10 22:06:46Z schroeer $
 
-Copyright 2004/2005 Daniel Schrer (L<http://www.danielschroeer.de>)
+Copyright 2004-2006 Daniel Schrer (L<http://www.danielschroeer.de>)
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
