@@ -1,11 +1,11 @@
-#$Id: HP34401A.pm 272 2005-12-12 00:56:50Z schroeer $
+#$Id: HP34401A.pm 339 2006-04-12 17:30:48Z schroeer $
 
 package Lab::Instrument::HP34401A;
 
 use strict;
 use Lab::Instrument;
 
-our $VERSION = sprintf("0.%04d", q$Revision: 272 $ =~ / (\d+) /);
+our $VERSION = sprintf("0.%04d", q$Revision: 339 $ =~ / (\d+) /);
 
 sub new {
     my $proto = shift;
@@ -123,6 +123,11 @@ sub scroll_message {
     $self->display_clear();
 }
 
+sub id {
+    my $self=shift;
+    $self->{vi}->Query('*IDN?');
+}
+
 1;
 
 =head1 NAME
@@ -138,6 +143,9 @@ Lab::Instrument::HP34401A - HP/Agilent 34401A digital multimeter
 
 =head1 DESCRIPTION
 
+The Lab::Instrument::HP34401A class implements an interface to the 34401A digital multimeter by
+Agilent (formerly HP).
+
 =head1 CONSTRUCTOR
 
     my $hp=new(\%options);
@@ -155,12 +163,13 @@ and resolution.
 
 =item $range
 
-Range is given in terms of volts and can be [0.1|1|10|100|1000|MIN|MAX|DEF]. DEF is default.
+Range is given in terms of volts and can be C<[0.1|1|10|100|1000|MIN|MAX|DEF]>. C<DEF> is default.
 
 =item $resolution
 
-Resolution is given in terms of $range or [MIN|MAX|DEF]. $resolution=0.0001 means 4 digits for example.
-The best resolution is 100nV: $range=0.1;$resolution=0.000001.
+Resolution is given in terms of C<$range> or C<[MIN|MAX|DEF]>.
+C<$resolution=0.0001> means 4 1/2 digits for example.
+The best resolution is 100nV: C<$range=0.1>;C<$resolution=0.000001>.
 
 =back
 
@@ -233,6 +242,12 @@ queue. Errors are retrieved in first-in-first out (FIFO) order.
 
 Reset the multimeter to its power-on configuration.
 
+=head2 id
+
+    $id=$hp->id();
+
+Returns the instruments ID string.
+
 =head1 CAVEATS/BUGS
 
 probably many
@@ -241,17 +256,15 @@ probably many
 
 =over 4
 
-=item Lab::Instrument
-
-The HP34401A uses the Lab::Instrument class (L<Lab::Instrument>).
+=item L<Lab::Instrument>
 
 =back
 
 =head1 AUTHOR/COPYRIGHT
 
-This is $Id: HP34401A.pm 272 2005-12-12 00:56:50Z schroeer $
+This is $Id: HP34401A.pm 339 2006-04-12 17:30:48Z schroeer $
 
-Copyright 2004 Daniel Schrer (L<http://www.danielschroeer.de>)
+Copyright 2004-2006 Daniel Schrer (L<http://www.danielschroeer.de>)
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
